lut!() { /* proc-macro */ }Expand description
Generates a numeric lookup function.
The macro is function-like and accepts an expression that looks like a closure. Only parameters
that use range patterns (like x @ 0..1) are accepted. All parameters are implicitly of type
usize since they will be used as indices for lookup tables.